@@ -285,7 +285,7 @@ func fakeKubeDeleteResponse(status int) *http.Response {
 
 	body := objBody(codec, &metav1.Status{Code: int32(status)})
 	return &http.Response{StatusCode: status, Body: body, Header: map[string][]string{
-		"Content-Type": []string{"application/json"},
+		"Content-Type": {"application/json"},
 	}}
 }
 
@@ -306,7 +306,7 @@ func TestCleanup(t *testing.T) {
 			Pod:  &api.Pod{ObjectMeta: objectMeta},
 			ClientFunc: func(req *http.Request) (*http.Response, error) {
 				switch p, m := req.URL.Path, req.Method; {
-				case m == "DELETE" && p == "/api/"+version+"/namespaces/test-ns/pods/test-resource":
+				case m == http.MethodDelete && p == "/api/"+version+"/namespaces/test-ns/pods/test-resource":
 					return fakeKubeDeleteResponse(http.StatusOK), nil
 				default:
 					return nil, fmt.Errorf("unexpected request. method: %s, path: %s", m, p)
@@ -326,7 +326,7 @@ func TestCleanup(t *testing.T) {
 			Pod:  &api.Pod{ObjectMeta: objectMeta},
 			ClientFunc: func(req *http.Request) (*http.Response, error) {
 				switch p, m := req.URL.Path, req.Method; {
-				case m == "DELETE" && p == "/api/"+version+"/namespaces/test-ns/pods/test-resource":
+				case m == http.MethodDelete && p == "/api/"+version+"/namespaces/test-ns/pods/test-resource":
 					return fakeKubeDeleteResponse(http.StatusNotFound), nil
 				default:
 					return nil, fmt.Errorf("unexpected request. method: %s, path: %s", m, p)
@@ -340,7 +340,7 @@ func TestCleanup(t *testing.T) {
 			Credentials: &api.Secret{ObjectMeta: objectMeta},
 			ClientFunc: func(req *http.Request) (*http.Response, error) {
 				switch p, m := req.URL.Path, req.Method; {
-				case m == "DELETE" && p == "/api/"+version+"/namespaces/test-ns/secrets/test-resource":
+				case m == http.MethodDelete && p == "/api/"+version+"/namespaces/test-ns/secrets/test-resource":
 					return fakeKubeDeleteResponse(http.StatusNotFound), nil
 				default:
 					return nil, fmt.Errorf("unexpected request. method: %s, path: %s", m, p)
@@ -1543,6 +1543,7 @@ func TestKubernetesNoRootImage(t *testing.T) {
 			RunnerSettings: common.RunnerSettings{
 				Executor: "kubernetes",
 				Kubernetes: &common.KubernetesConfig{
+					Image:      common.TestAlpineImage,
 					PullPolicy: common.PullPolicyIfNotPresent,
 				},
 			},
@@ -1553,6 +1554,52 @@ func TestKubernetesNoRootImage(t *testing.T) {
 	assert.NoError(t, err)
 }
 
+func TestKubernetesCustomClonePath(t *testing.T) {
+	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
+		return
+	}
+
+	jobResponse, err := common.GetRemoteBuildResponse(
+		"ls -al $CI_BUILDS_DIR/go/src/gitlab.com/gitlab-org/repo")
+	require.NoError(t, err)
+
+	tests := map[string]struct {
+		clonePath         string
+		expectedErrorType interface{}
+	}{
+		"uses custom clone path": {
+			clonePath:         "$CI_BUILDS_DIR/go/src/gitlab.com/gitlab-org/repo",
+			expectedErrorType: nil,
+		},
+		"path has to be within CI_BUILDS_DIR": {
+			clonePath:         "/unknown/go/src/gitlab.com/gitlab-org/repo",
+			expectedErrorType: &common.BuildError{},
+		},
+	}
+
+	for name, test := range tests {
+		t.Run(name, func(t *testing.T) {
+			build := &common.Build{
+				JobResponse: jobResponse,
+				Runner: &common.RunnerConfig{
+					RunnerSettings: common.RunnerSettings{
+						Executor: "kubernetes",
+						Kubernetes: &common.KubernetesConfig{
+							Image:      common.TestAlpineImage,
+							PullPolicy: common.PullPolicyIfNotPresent,
+						},
+						Environment: []string{
+							"GIT_CLONE_PATH=" + test.clonePath,
+						},
+					},
+				},
+			}
+
+			err = build.Run(&common.Config{}, &common.Trace{Writer: os.Stdout})
+			assert.IsType(t, test.expectedErrorType, err)
+		})
+	}
+}
 func TestKubernetesBuildFail(t *testing.T) {
 	if helpers.SkipIntegrationTests(t, "kubectl", "cluster-info") {
 		return
